# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

"""
TopLoc module, see official documentation at
https://dev.opencascade.org/doc/occt-7.9.0/refman/html/package_toploc.html
"""

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _TopLoc
else:
    import _TopLoc

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TopLoc.delete_SwigPyIterator

    def value(self):
        return _TopLoc.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _TopLoc.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _TopLoc.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _TopLoc.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _TopLoc.SwigPyIterator_equal(self, x)

    def copy(self):
        return _TopLoc.SwigPyIterator_copy(self)

    def next(self):
        return _TopLoc.SwigPyIterator_next(self)

    def __next__(self):
        return _TopLoc.SwigPyIterator___next__(self)

    def previous(self):
        return _TopLoc.SwigPyIterator_previous(self)

    def advance(self, n):
        return _TopLoc.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _TopLoc.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _TopLoc.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _TopLoc.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _TopLoc.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _TopLoc.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _TopLoc.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TopLoc:
_TopLoc.SwigPyIterator_swigregister(SwigPyIterator)

def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error, method_name, class_name):
    return _TopLoc.process_exception(error, method_name, class_name)

import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

class ios_base(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    erase_event = _TopLoc.ios_base_erase_event
    imbue_event = _TopLoc.ios_base_imbue_event
    copyfmt_event = _TopLoc.ios_base_copyfmt_event

    def register_callback(self, __fn, __index):
        return _TopLoc.ios_base_register_callback(self, __fn, __index)

    def flags(self, *args):
        return _TopLoc.ios_base_flags(self, *args)

    def setf(self, *args):
        return _TopLoc.ios_base_setf(self, *args)

    def unsetf(self, __mask):
        return _TopLoc.ios_base_unsetf(self, __mask)

    def precision(self, *args):
        return _TopLoc.ios_base_precision(self, *args)

    def width(self, *args):
        return _TopLoc.ios_base_width(self, *args)

    @staticmethod
    def sync_with_stdio(__sync=True):
        return _TopLoc.ios_base_sync_with_stdio(__sync)

    def imbue(self, __loc):
        return _TopLoc.ios_base_imbue(self, __loc)

    def getloc(self):
        return _TopLoc.ios_base_getloc(self)

    @staticmethod
    def xalloc():
        return _TopLoc.ios_base_xalloc()

    def iword(self, __ix):
        return _TopLoc.ios_base_iword(self, __ix)

    def pword(self, __ix):
        return _TopLoc.ios_base_pword(self, __ix)
    __swig_destroy__ = _TopLoc.delete_ios_base

# Register ios_base in _TopLoc:
_TopLoc.ios_base_swigregister(ios_base)
cvar = _TopLoc.cvar
ios_base.boolalpha = _TopLoc.cvar.ios_base_boolalpha
ios_base.dec = _TopLoc.cvar.ios_base_dec
ios_base.fixed = _TopLoc.cvar.ios_base_fixed
ios_base.hex = _TopLoc.cvar.ios_base_hex
ios_base.internal = _TopLoc.cvar.ios_base_internal
ios_base.left = _TopLoc.cvar.ios_base_left
ios_base.oct = _TopLoc.cvar.ios_base_oct
ios_base.right = _TopLoc.cvar.ios_base_right
ios_base.scientific = _TopLoc.cvar.ios_base_scientific
ios_base.showbase = _TopLoc.cvar.ios_base_showbase
ios_base.showpoint = _TopLoc.cvar.ios_base_showpoint
ios_base.showpos = _TopLoc.cvar.ios_base_showpos
ios_base.skipws = _TopLoc.cvar.ios_base_skipws
ios_base.unitbuf = _TopLoc.cvar.ios_base_unitbuf
ios_base.uppercase = _TopLoc.cvar.ios_base_uppercase
ios_base.adjustfield = _TopLoc.cvar.ios_base_adjustfield
ios_base.basefield = _TopLoc.cvar.ios_base_basefield
ios_base.floatfield = _TopLoc.cvar.ios_base_floatfield
ios_base.badbit = _TopLoc.cvar.ios_base_badbit
ios_base.eofbit = _TopLoc.cvar.ios_base_eofbit
ios_base.failbit = _TopLoc.cvar.ios_base_failbit
ios_base.goodbit = _TopLoc.cvar.ios_base_goodbit
ios_base.app = _TopLoc.cvar.ios_base_app
ios_base.ate = _TopLoc.cvar.ios_base_ate
ios_base.binary = _TopLoc.cvar.ios_base_binary
ios_base.ios_base_in = _TopLoc.cvar.ios_base_ios_base_in
ios_base.out = _TopLoc.cvar.ios_base_out
ios_base.trunc = _TopLoc.cvar.ios_base_trunc
ios_base.beg = _TopLoc.cvar.ios_base_beg
ios_base.cur = _TopLoc.cvar.ios_base_cur
ios_base.end = _TopLoc.cvar.ios_base_end

class ios(ios_base):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def rdstate(self):
        return _TopLoc.ios_rdstate(self)

    def clear(self, *args):
        return _TopLoc.ios_clear(self, *args)

    def setstate(self, __state):
        return _TopLoc.ios_setstate(self, __state)

    def good(self):
        return _TopLoc.ios_good(self)

    def eof(self):
        return _TopLoc.ios_eof(self)

    def fail(self):
        return _TopLoc.ios_fail(self)

    def bad(self):
        return _TopLoc.ios_bad(self)

    def exceptions(self, *args):
        return _TopLoc.ios_exceptions(self, *args)

    def __init__(self, __sb):
        _TopLoc.ios_swiginit(self, _TopLoc.new_ios(__sb))
    __swig_destroy__ = _TopLoc.delete_ios

    def tie(self, *args):
        return _TopLoc.ios_tie(self, *args)

    def rdbuf(self, *args):
        return _TopLoc.ios_rdbuf(self, *args)

    def copyfmt(self, __rhs):
        return _TopLoc.ios_copyfmt(self, __rhs)

    def fill(self, *args):
        return _TopLoc.ios_fill(self, *args)

    def imbue(self, __loc):
        return _TopLoc.ios_imbue(self, __loc)

    def narrow(self, __c, __dfault):
        return _TopLoc.ios_narrow(self, __c, __dfault)

    def widen(self, __c):
        return _TopLoc.ios_widen(self, __c)

# Register ios in _TopLoc:
_TopLoc.ios_swigregister(ios)
class ostream(ios):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _TopLoc.ostream_swiginit(self, _TopLoc.new_ostream(__sb))
    __swig_destroy__ = _TopLoc.delete_ostream

    def __lshift__(self, *args):
        return _TopLoc.ostream___lshift__(self, *args)

    def put(self, __c):
        return _TopLoc.ostream_put(self, __c)

    def write(self, __s, __n):
        return _TopLoc.ostream_write(self, __s, __n)

    def flush(self):
        return _TopLoc.ostream_flush(self)

    def tellp(self):
        return _TopLoc.ostream_tellp(self)

    def seekp(self, *args):
        return _TopLoc.ostream_seekp(self, *args)

# Register ostream in _TopLoc:
_TopLoc.ostream_swigregister(ostream)
class istream(ios):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _TopLoc.istream_swiginit(self, _TopLoc.new_istream(__sb))
    __swig_destroy__ = _TopLoc.delete_istream

    def __rshift__(self, *args):
        return _TopLoc.istream___rshift__(self, *args)

    def gcount(self):
        return _TopLoc.istream_gcount(self)

    def get(self, *args):
        return _TopLoc.istream_get(self, *args)

    def getline(self, *args):
        return _TopLoc.istream_getline(self, *args)

    def ignore(self, *args):
        return _TopLoc.istream_ignore(self, *args)

    def peek(self):
        return _TopLoc.istream_peek(self)

    def read(self, __s, __n):
        return _TopLoc.istream_read(self, __s, __n)

    def readsome(self, __s, __n):
        return _TopLoc.istream_readsome(self, __s, __n)

    def putback(self, __c):
        return _TopLoc.istream_putback(self, __c)

    def unget(self):
        return _TopLoc.istream_unget(self)

    def sync(self):
        return _TopLoc.istream_sync(self)

    def tellg(self):
        return _TopLoc.istream_tellg(self)

    def seekg(self, *args):
        return _TopLoc.istream_seekg(self, *args)

# Register istream in _TopLoc:
_TopLoc.istream_swigregister(istream)
class iostream(istream, ostream):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _TopLoc.iostream_swiginit(self, _TopLoc.new_iostream(__sb))
    __swig_destroy__ = _TopLoc.delete_iostream

# Register iostream in _TopLoc:
_TopLoc.iostream_swigregister(iostream)
cin = cvar.cin
cout = cvar.cout
cerr = cvar.cerr
clog = cvar.clog

endl_cb_ptr = _TopLoc.endl_cb_ptr
endl = _TopLoc.endl
ends_cb_ptr = _TopLoc.ends_cb_ptr
ends = _TopLoc.ends
flush_cb_ptr = _TopLoc.flush_cb_ptr
flush = _TopLoc.flush
import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_TopLoc_Datum3D_Create():
    return _TopLoc.Handle_TopLoc_Datum3D_Create()

def Handle_TopLoc_Datum3D_DownCast(t):
    return _TopLoc.Handle_TopLoc_Datum3D_DownCast(t)

def Handle_TopLoc_Datum3D_IsNull(t):
    return _TopLoc.Handle_TopLoc_Datum3D_IsNull(t)

def Handle_TopLoc_SListNodeOfItemLocation_Create():
    return _TopLoc.Handle_TopLoc_SListNodeOfItemLocation_Create()

def Handle_TopLoc_SListNodeOfItemLocation_DownCast(t):
    return _TopLoc.Handle_TopLoc_SListNodeOfItemLocation_DownCast(t)

def Handle_TopLoc_SListNodeOfItemLocation_IsNull(t):
    return _TopLoc.Handle_TopLoc_SListNodeOfItemLocation_IsNull(t)
class TopLoc_IndexedMapOfLocation(OCC.Core.NCollection.NCollection_BaseMap):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def cbegin(self):
        return _TopLoc.TopLoc_IndexedMapOfLocation_cbegin(self)

    def cend(self):
        return _TopLoc.TopLoc_IndexedMapOfLocation_cend(self)

    def __init__(self, *args):
        _TopLoc.TopLoc_IndexedMapOfLocation_swiginit(self, _TopLoc.new_TopLoc_IndexedMapOfLocation(*args))

    def Exchange(self, theOther):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Exchange(self, theOther)

    def Assign(self, theOther):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Assign(self, theOther)

    def Set(self, *args):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Set(self, *args)

    def ReSize(self, theExtent):
        return _TopLoc.TopLoc_IndexedMapOfLocation_ReSize(self, theExtent)

    def Add(self, *args):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Add(self, *args)

    def Contains(self, theKey1):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Contains(self, theKey1)

    def Substitute(self, theIndex, theKey1):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Substitute(self, theIndex, theKey1)

    def Swap(self, theIndex1, theIndex2):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Swap(self, theIndex1, theIndex2)

    def RemoveLast(self):
        return _TopLoc.TopLoc_IndexedMapOfLocation_RemoveLast(self)

    def RemoveFromIndex(self, theIndex):
        return _TopLoc.TopLoc_IndexedMapOfLocation_RemoveFromIndex(self, theIndex)

    def RemoveKey(self, theKey1):
        return _TopLoc.TopLoc_IndexedMapOfLocation_RemoveKey(self, theKey1)

    def FindKey(self, theIndex):
        return _TopLoc.TopLoc_IndexedMapOfLocation_FindKey(self, theIndex)

    def __call__(self, theIndex):
        return _TopLoc.TopLoc_IndexedMapOfLocation___call__(self, theIndex)

    def FindIndex(self, theKey1):
        return _TopLoc.TopLoc_IndexedMapOfLocation_FindIndex(self, theKey1)

    def Clear(self, *args):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Clear(self, *args)
    __swig_destroy__ = _TopLoc.delete_TopLoc_IndexedMapOfLocation

    def Size(self):
        return _TopLoc.TopLoc_IndexedMapOfLocation_Size(self)

# Register TopLoc_IndexedMapOfLocation in _TopLoc:
_TopLoc.TopLoc_IndexedMapOfLocation_swigregister(TopLoc_IndexedMapOfLocation)
class TopLoc_MapOfLocation(OCC.Core.NCollection.NCollection_BaseMap):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def cbegin(self):
        return _TopLoc.TopLoc_MapOfLocation_cbegin(self)

    def cend(self):
        return _TopLoc.TopLoc_MapOfLocation_cend(self)

    def __init__(self, *args):
        _TopLoc.TopLoc_MapOfLocation_swiginit(self, _TopLoc.new_TopLoc_MapOfLocation(*args))

    def Exchange(self, theOther):
        return _TopLoc.TopLoc_MapOfLocation_Exchange(self, theOther)

    def Assign(self, theOther):
        return _TopLoc.TopLoc_MapOfLocation_Assign(self, theOther)

    def Set(self, *args):
        return _TopLoc.TopLoc_MapOfLocation_Set(self, *args)

    def ReSize(self, N):
        return _TopLoc.TopLoc_MapOfLocation_ReSize(self, N)

    def Add(self, *args):
        return _TopLoc.TopLoc_MapOfLocation_Add(self, *args)

    def Added(self, *args):
        return _TopLoc.TopLoc_MapOfLocation_Added(self, *args)

    def Remove(self, K):
        return _TopLoc.TopLoc_MapOfLocation_Remove(self, K)

    def Clear(self, *args):
        return _TopLoc.TopLoc_MapOfLocation_Clear(self, *args)
    __swig_destroy__ = _TopLoc.delete_TopLoc_MapOfLocation

    def Size(self):
        return _TopLoc.TopLoc_MapOfLocation_Size(self)

    def IsEqual(self, theOther):
        return _TopLoc.TopLoc_MapOfLocation_IsEqual(self, theOther)

    def Contains(self, *args):
        return _TopLoc.TopLoc_MapOfLocation_Contains(self, *args)

    def Union(self, theLeft, theRight):
        return _TopLoc.TopLoc_MapOfLocation_Union(self, theLeft, theRight)

    def Unite(self, theOther):
        return _TopLoc.TopLoc_MapOfLocation_Unite(self, theOther)

    def HasIntersection(self, theMap):
        return _TopLoc.TopLoc_MapOfLocation_HasIntersection(self, theMap)

    def Intersection(self, theLeft, theRight):
        return _TopLoc.TopLoc_MapOfLocation_Intersection(self, theLeft, theRight)

    def Intersect(self, theOther):
        return _TopLoc.TopLoc_MapOfLocation_Intersect(self, theOther)

    def Subtraction(self, theLeft, theRight):
        return _TopLoc.TopLoc_MapOfLocation_Subtraction(self, theLeft, theRight)

    def Subtract(self, theOther):
        return _TopLoc.TopLoc_MapOfLocation_Subtract(self, theOther)

    def Difference(self, theLeft, theRight):
        return _TopLoc.TopLoc_MapOfLocation_Difference(self, theLeft, theRight)

    def Differ(self, theOther):
        return _TopLoc.TopLoc_MapOfLocation_Differ(self, theOther)

# Register TopLoc_MapOfLocation in _TopLoc:
_TopLoc.TopLoc_MapOfLocation_swigregister(TopLoc_MapOfLocation)
class TopLoc_Datum3D(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Constructs a default Datum3D.

        Parameters
        ----------
        T: gp_Trsf

        Return
        -------
        None

        Description
        -----------
        Constructs a Datum3D form a Trsf from gp. An error is raised if the Trsf is not a rigid transformation.

        """
        _TopLoc.TopLoc_Datum3D_swiginit(self, _TopLoc.new_TopLoc_Datum3D(*args))

    def DumpJson(self, depth=-1):
        r"""

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        """
        return _TopLoc.TopLoc_Datum3D_DumpJson(self, depth)

    def Form(self, *args):
        r"""
        Return
        -------
        gp_TrsfForm

        Description
        -----------
        Return transformation form.

        """
        return _TopLoc.TopLoc_Datum3D_Form(self, *args)

    def ShallowDump(self, *args):
        r"""

        Parameters
        ----------

        Return
        -------
        S: Standard_OStream

        Description
        -----------
        Writes the contents of this Datum3D to the stream S.

        """
        return _TopLoc.TopLoc_Datum3D_ShallowDump(self, *args)

    def Transformation(self, *args):
        r"""
        Return
        -------
        gp_Trsf

        Description
        -----------
        Returns a gp_Trsf which, when applied to this datum, produces the default datum.

        """
        return _TopLoc.TopLoc_Datum3D_Transformation(self, *args)

    def Trsf(self, *args):
        r"""
        Return
        -------
        gp_Trsf

        Description
        -----------
        Returns a gp_Trsf which, when applied to this datum, produces the default datum.

        """
        return _TopLoc.TopLoc_Datum3D_Trsf(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TopLoc_Datum3D_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TopLoc.delete_TopLoc_Datum3D

# Register TopLoc_Datum3D in _TopLoc:
_TopLoc.TopLoc_Datum3D_swigregister(TopLoc_Datum3D)
class TopLoc_ItemLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""

        Parameters
        ----------
        D: TopLoc_Datum3D
        P: int

        Return
        -------
        None

        Description
        -----------
        Sets the elementary Datum to <D> Sets the exponent to <P>.

        """
        _TopLoc.TopLoc_ItemLocation_swiginit(self, _TopLoc.new_TopLoc_ItemLocation(*args))

    def DumpJson(self, depth=-1):
        r"""

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        """
        return _TopLoc.TopLoc_ItemLocation_DumpJson(self, depth)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopLoc.delete_TopLoc_ItemLocation

# Register TopLoc_ItemLocation in _TopLoc:
_TopLoc.TopLoc_ItemLocation_swigregister(TopLoc_ItemLocation)
class TopLoc_Location(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Constructs an empty local coordinate system object. Note: A Location constructed from a default datum is said to be 'empty'.

        Parameters
        ----------
        T: gp_Trsf

        Return
        -------
        None

        Description
        -----------
        Constructs the local coordinate system object defined by the transformation T. T invokes in turn, a TopLoc_Datum3D object.

        Parameters
        ----------
        D: TopLoc_Datum3D

        Return
        -------
        None

        Description
        -----------
        Constructs the local coordinate system object defined by the 3D datum D. Exceptions Standard_ConstructionError if the transformation T does not represent a 3D coordinate system.

        """
        _TopLoc.TopLoc_Location_swiginit(self, _TopLoc.new_TopLoc_Location(*args))

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Clear myItems.

        """
        return _TopLoc.TopLoc_Location_Clear(self, *args)

    def Divided(self, *args):
        r"""

        Parameters
        ----------
        Other: TopLoc_Location

        Return
        -------
        TopLoc_Location

        Description
        -----------
        Returns <self> / <Other>.

        """
        return _TopLoc.TopLoc_Location_Divided(self, *args)

    def DumpJson(self, depth=-1):
        r"""

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        Parameters
        ----------
        depth: int, default=-1

        Return
        -------
        str

        Description
        -----------
        Dump the object to JSON string.

        """
        return _TopLoc.TopLoc_Location_DumpJson(self, depth)

    def FirstDatum(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopLoc_Datum3D>

        Description
        -----------
        Returns the first elementary datum of the Location. Use the NextLocation function recursively to access the other data comprising this location. Exceptions Standard_NoSuchObject if this location is empty.

        """
        return _TopLoc.TopLoc_Location_FirstDatum(self, *args)

    def FirstPower(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the power elevation of the first elementary datum. Exceptions Standard_NoSuchObject if this location is empty.

        """
        return _TopLoc.TopLoc_Location_FirstPower(self, *args)

    def HashCode(self, *args):
        r"""
        Return
        -------
        size_t

        Description
        -----------
        Returns a hashed value for this local coordinate system. This value is used, with map tables, to store and retrieve the object easily 
        Return: a computed hash code.

        """
        return _TopLoc.TopLoc_Location_HashCode(self, *args)

    def Identity(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Resets this location to the Identity transformation.

        """
        return _TopLoc.TopLoc_Location_Identity(self, *args)

    def Inverted(self, *args):
        r"""
        Return
        -------
        TopLoc_Location

        Description
        -----------
        Returns the inverse of <self>. //! <self> * Inverted() is an Identity.

        """
        return _TopLoc.TopLoc_Location_Inverted(self, *args)

    def IsDifferent(self, *args):
        r"""

        Parameters
        ----------
        Other: TopLoc_Location

        Return
        -------
        bool

        Description
        -----------
        Returns true if this location and the location Other do not have the same elementary data, i.e. do not contain the same series of TopLoc_Datum3D and respective powers. This method is an alias for operator !=.

        """
        return _TopLoc.TopLoc_Location_IsDifferent(self, *args)

    def IsEqual(self, *args):
        r"""

        Parameters
        ----------
        Other: TopLoc_Location

        Return
        -------
        bool

        Description
        -----------
        Returns true if this location and the location Other have the same elementary data, i.e. contain the same series of TopLoc_Datum3D and respective powers. This method is an alias for operator ==.

        """
        return _TopLoc.TopLoc_Location_IsEqual(self, *args)

    def IsIdentity(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Returns true if this location is equal to the Identity transformation.

        """
        return _TopLoc.TopLoc_Location_IsIdentity(self, *args)

    def Multiplied(self, *args):
        r"""

        Parameters
        ----------
        Other: TopLoc_Location

        Return
        -------
        TopLoc_Location

        Description
        -----------
        Returns <self> * <Other>, the elementary datums are concatenated.

        """
        return _TopLoc.TopLoc_Location_Multiplied(self, *args)

    def NextLocation(self, *args):
        r"""
        Return
        -------
        TopLoc_Location

        Description
        -----------
        Returns a Location representing <self> without the first datum. We have the relation: //! <self> = NextLocation() * FirstDatum() ^ FirstPower() Exceptions Standard_NoSuchObject if this location is empty.

        """
        return _TopLoc.TopLoc_Location_NextLocation(self, *args)

    def Powered(self, *args):
        r"""

        Parameters
        ----------
        pwr: int

        Return
        -------
        TopLoc_Location

        Description
        -----------
        Returns me at the power <pwr>. If <pwr> is zero returns Identity. <pwr> can be lower than zero (usual meaning for powers).

        """
        return _TopLoc.TopLoc_Location_Powered(self, *args)

    def Predivided(self, *args):
        r"""

        Parameters
        ----------
        Other: TopLoc_Location

        Return
        -------
        TopLoc_Location

        Description
        -----------
        Returns <Other>.Inverted() * <self>.

        """
        return _TopLoc.TopLoc_Location_Predivided(self, *args)

    @staticmethod
    def ScalePrec(*args):
        r"""
        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopLoc.TopLoc_Location_ScalePrec(*args)

    def ShallowDump(self, *args):
        r"""

        Parameters
        ----------

        Return
        -------
        S: Standard_OStream

        Description
        -----------
        Prints the contents of <self> on the stream <s>.

        """
        return _TopLoc.TopLoc_Location_ShallowDump(self, *args)

    def Transformation(self, *args):
        r"""
        Return
        -------
        gp_Trsf

        Description
        -----------
        Returns the transformation associated to the coordinate system.

        """
        return _TopLoc.TopLoc_Location_Transformation(self, *args)

    def __ne_wrapper__(self, other):
        return _TopLoc.TopLoc_Location___ne_wrapper__(self, other)

    def __ne__(self, right):
        try:
            return self.__ne_wrapper__(right)
        except:
            return True


    def __mul__(self, *args):
        r"""

        Parameters
        ----------
        Other: TopLoc_Location

        Return
        -------
        TopLoc_Location

        Description
        -----------
        No available documentation.

        """
        return _TopLoc.TopLoc_Location___mul__(self, *args)

    def __truediv__(self, *args):
        return _TopLoc.TopLoc_Location___truediv__(self, *args)
    __div__ = __truediv__



    def __eq_wrapper__(self, other):
        return _TopLoc.TopLoc_Location___eq_wrapper__(self, other)

    def __eq__(self, right):
        try:
            return self.__eq_wrapper__(right)
        except:
            return False


    __repr__ = _dumps_object

    __swig_destroy__ = _TopLoc.delete_TopLoc_Location

# Register TopLoc_Location in _TopLoc:
_TopLoc.TopLoc_Location_swigregister(TopLoc_Location)
class TopLoc_SListNodeOfItemLocation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""

        Parameters
        ----------
        I: TopLoc_ItemLocation
        aTail: TopLoc_SListOfItemLocation

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopLoc.TopLoc_SListNodeOfItemLocation_swiginit(self, _TopLoc.new_TopLoc_SListNodeOfItemLocation(*args))

    def Tail(self, *args):
        r"""
        Return
        -------
        TopLoc_SListOfItemLocation

        Description
        -----------
        No available documentation.

        """
        return _TopLoc.TopLoc_SListNodeOfItemLocation_Tail(self, *args)

    def Value(self, *args):
        r"""
        Return
        -------
        TopLoc_ItemLocation

        Description
        -----------
        No available documentation.

        """
        return _TopLoc.TopLoc_SListNodeOfItemLocation_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TopLoc_SListNodeOfItemLocation_DownCast(t)


    __repr__ = _dumps_object

    @methodnotwrapped
    def Count(self):
    	pass

    __swig_destroy__ = _TopLoc.delete_TopLoc_SListNodeOfItemLocation

# Register TopLoc_SListNodeOfItemLocation in _TopLoc:
_TopLoc.TopLoc_SListNodeOfItemLocation_swigregister(TopLoc_SListNodeOfItemLocation)
class TopLoc_SListOfItemLocation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Creates an empty List.

        Parameters
        ----------
        anItem: TopLoc_ItemLocation
        aTail: TopLoc_SListOfItemLocation

        Return
        -------
        None

        Description
        -----------
        Creates a List with <anItem> as value and <aTail> as tail.

        Parameters
        ----------
        Other: TopLoc_SListOfItemLocation

        Return
        -------
        None

        Description
        -----------
        Creates a list from an other one. The lists are shared.

        Parameters
        ----------
        theOther: TopLoc_SListOfItemLocation

        Return
        -------
        None

        Description
        -----------
        Move constructor.

        """
        _TopLoc.TopLoc_SListOfItemLocation_swiginit(self, _TopLoc.new_TopLoc_SListOfItemLocation(*args))

    def Assign(self, *args):
        r"""

        Parameters
        ----------
        Other: TopLoc_SListOfItemLocation

        Return
        -------
        TopLoc_SListOfItemLocation

        Description
        -----------
        Sets a list from an other one. The lists are shared. The list itself is returned.

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Assign(self, *args)

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Sets the list to be empty.

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Clear(self, *args)

    def Construct(self, *args):
        r"""

        Parameters
        ----------
        anItem: TopLoc_ItemLocation

        Return
        -------
        None

        Description
        -----------
        Replaces the list by a list with <anItem> as Value and the list <self> as tail.

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Construct(self, *args)

    def IsEmpty(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Return true if this list is empty.

        """
        return _TopLoc.TopLoc_SListOfItemLocation_IsEmpty(self, *args)

    def More(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Returns True if the iterator has a current value. This is !IsEmpty().

        """
        return _TopLoc.TopLoc_SListOfItemLocation_More(self, *args)

    def Next(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Moves the iterator to the next object in the list. If the iterator is empty it will stay empty. This is ToTail().

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Next(self, *args)

    def Tail(self, *args):
        r"""
        Return
        -------
        TopLoc_SListOfItemLocation

        Description
        -----------
        Returns the current tail of the list. On an empty list the tail is the list itself.

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Tail(self, *args)

    def ToTail(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Replaces the list <self> by its tail.

        """
        return _TopLoc.TopLoc_SListOfItemLocation_ToTail(self, *args)

    def Value(self, *args):
        r"""
        Return
        -------
        TopLoc_ItemLocation

        Description
        -----------
        Returns the current value of the list. An error is raised if the list is empty.

        """
        return _TopLoc.TopLoc_SListOfItemLocation_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopLoc.delete_TopLoc_SListOfItemLocation

# Register TopLoc_SListOfItemLocation in _TopLoc:
_TopLoc.TopLoc_SListOfItemLocation_swigregister(TopLoc_SListOfItemLocation)



@deprecated
def TopLoc_Location_ScalePrec(*args):
	return TopLoc_Location.ScalePrec(*args)



